import { defHttp } from '@/utils/axios/index'
import type { MenuPermissionDto, MenuPermissionInfo } from './model/menuModel'
import type { ApiResult, ApiResultRecord } from '../model/baseModel'
import { ContentTypeEnum } from '@/enums/httpEnums'

enum Api {
  // 获取菜单列表
  MENU_INSERT = '/permission/save',
  MENU_LIST_TREE = '/permission/treeList',
  MENU_LIST = '/permission/findAll',
  MENU_FINDBYID = '/permission/findById',
  MENU_DELETE = '/permission/delete',
  MENU_UPDATE = '/permission/update'
}

export const apiInsertMenu = (data: MenuPermissionDto) => {
  return defHttp.post<ApiResult<MenuPermissionInfo>>({
    url: Api.MENU_INSERT,
    data
  })
}

export const apiGetMenuListTree = () => {
  return defHttp.get<ApiResult<MenuPermissionInfo[]>>({
    url: Api.MENU_LIST_TREE,
    headers: {
      'Content-Type': ContentTypeEnum.FORM_URLENCODED
    }
  })
}

export const apiGetMenuList = () => {
  return defHttp.get<ApiResult<MenuPermissionInfo[]>>({
    url: Api.MENU_LIST,
    headers: {
      'Content-Type': ContentTypeEnum.FORM_URLENCODED
    }
  })
}

export const apiFindMenuById = (params: { id: string }) => {
  return defHttp.get<ApiResult<MenuPermissionInfo>>({
    url: Api.MENU_FINDBYID,
    params,
    headers: {
      'Content-Type': ContentTypeEnum.FORM_URLENCODED
    }
  })
}

export const apiDeleteMenuById = (params: { ids: string }) => {
  return defHttp.delete<ApiResult>({
    url: Api.MENU_DELETE,
    params,
    headers: {
      'Content-Type': ContentTypeEnum.FORM_URLENCODED
    }
  })
}

export const apiUpdateMenu = (data: MenuPermissionDto) => {
  return defHttp.post<ApiResult>({
    url: Api.MENU_UPDATE,
    data
  })
}
