import { ContentTypeEnum } from '@/enums/httpEnums'
import { defHttp } from '@/utils/axios/index'
import type { ApiResult, ApiResultRecord } from '../model/baseModel'
import type { OrgDto, OrgModel } from './model/orgModel'

enum Api {
  // 查询机构
  ORG_LIST = '/org/findAll',
  // 根据id 查询
  ORG_FINDBYID = '/org/findById',
  // 新增
  ORG_SAVE = '/org/save',
  // 获取机构树
  ORG_TREE = '/org/treeResult',
  // 修改组织机构
  ORG_UPDATE = '/org/update',
  // 删除组织
  ORG_DELETE = '/org/deleteByIds',
}

export type OrgTreeModel = OrgModel & {
    childNode: OrgModel[]
}

export const apiGetOrgList = () => {
    return defHttp.get<ApiResult<OrgModel[]>>({
        url: Api.ORG_LIST,
        headers: {
            'Content-Type': ContentTypeEnum.FORM_URLENCODED
        }
    })
}

export const apiInsertOrg = (data: OrgDto) => {
    return defHttp.post<ApiResult<OrgModel>>({
        url: Api.ORG_SAVE,
        data
    })
}

export const apiUpdateOrg = (data: OrgDto) => {
    return defHttp.post<ApiResult<OrgModel>>({
        url: Api.ORG_UPDATE,
        data
    })
}

export const apiDeleteOrg = (params: {ids: string}) => {
    return defHttp.delete<ApiResult>({
        url: Api.ORG_DELETE,
        params,
        headers: {
            "Content-Type": ContentTypeEnum.FORM_URLENCODED
        }
    })
}

export const apiGetOrgTree = () => {
    return defHttp.get<ApiResult<OrgTreeModel[]>>({
        url: Api.ORG_TREE,
        headers: {
            "Content-Type": ContentTypeEnum.FORM_URLENCODED
        }
    })
}
