import { ContentTypeEnum } from '@/enums/httpEnums'
import { defHttp } from '@/utils/axios/index'
import type { RoleDto, RoleInfo } from './model/roleModel'
import type { ApiResult, ApiResultRecord } from '../model/baseModel'

enum Api {
  insertRole = '/role/save',
  updateRole = '/role/update',
  getRolesList = '/role/page',
  deleteRole = '/role/deleteByIds',
  getRole = '/role/findById',
  rolePer = '/rolePer/save',
  getRolePer = '/rolePer/findByRoleId',
  roleFindUser = '/role/findByUserId',

}

export const apiInsertRole = (data: RoleDto) => {
  return defHttp.post<ApiResult<RoleInfo>>({
    url: Api.insertRole,
    data
  })
}
export const apiUpdateRole = (data: RoleDto) => {
  return defHttp.post<ApiResult<RoleInfo>>({
    url: Api.updateRole,
    data
  })
}
export const apiDeleteRole = (params: { ids: string }) => {
  return defHttp.delete<ApiResult>({
    url: Api.deleteRole,
    params,
    headers: {
      'Content-Type': ContentTypeEnum.FORM_URLENCODED
    }
  })
}
export const apiGetRole = (params: { id: string }) => {
  return defHttp.get<ApiResult<RoleInfo>>({
    url: Api.getRole,
    params,
    headers: {
      'Content-Type': ContentTypeEnum.FORM_URLENCODED
    }
  })
}
export const apiGetRoleList = () => {
  return defHttp.get<ApiResult<ApiResultRecord<RoleInfo[]>>>({
    url: Api.getRolesList,
    headers: {
      'Content-Type': ContentTypeEnum.FORM_URLENCODED
    }
  })
}
export const apiRolePerSave = (params: any) => {
  return defHttp.post<ApiResult>({
    url: Api.rolePer,
    params,
    headers: {
      'Content-Type': ContentTypeEnum.FORM_URLENCODED
    }
  })
}
export const apiGetRolePer = (params: any) => {
  return defHttp.get<ApiResult<string[]>>({
    url: Api.getRolePer,
    params,
    headers: {
      'Content-Type': ContentTypeEnum.FORM_URLENCODED
    }
  })
}

export const apiFindUserByRole = (params: {userId: string}) => {
  return defHttp.get<ApiResult<RoleInfo[]>>({
    url: Api.roleFindUser,
    params,
    headers: {
      'Content-Type': ContentTypeEnum.FORM_URLENCODED
    }
  })
}
