import { useUserStore } from '@/stores/modules/user'
import type { RouteRecordRaw, Router } from 'vue-router'
import { PAGE_NOT_FOUND_ROUTE } from '../routes/basic'
import { PageEnum } from '@/enums/pageEnums'
import { usePermissionStore } from '@/stores/modules/permission'

const whitePathList = ['/login']

export function createPermissionGuard(router: Router) {
  const userStore = useUserStore()
  const permissionStore = usePermissionStore()

  router.beforeEach(async (to, from, next) => {
    const token = userStore.getToken

    if (whitePathList.includes(to.path)) {
      if (to.path === '/login' && token) {
        try {
          await userStore.afterLoginAction()
          next({ path: '/' })
          return
        } catch {
          //
        }
      }
      next()
      return
    }

    // token or user does not exist
    if (!token) {
      // redirect login page
      const redirectData: { path: string; replace: boolean; query?: Recordable<string> } = {
        path: '/login',
        replace: true
      }
      if (to.path) {
        redirectData.query = {
          ...redirectData.query,
          redirect: to.path
        }
      }
      next(redirectData)
      return
    }

    // Jump to the 404 page after processing the login
    if (
      from.path === '/login' &&
      to.name === PAGE_NOT_FOUND_ROUTE.name &&
      to.fullPath !== PageEnum.BASE_HOME
    ) {
      next(PageEnum.BASE_HOME)
      return
    }

    if (permissionStore.getIsDynamicAddedRoute) {
      next()
      return
    }

    const routes = await permissionStore.buildRoutesAction()

    routes.forEach((route) => {
      router.addRoute(route as unknown as RouteRecordRaw)
    })
    
    permissionStore.setIsDynamicAddedRoute(true)

    if (to.name === PAGE_NOT_FOUND_ROUTE.name) {
      // 动态添加路由后，此处应当重定向到fullPath，否则会加载404页面内容
      next({ path: to.fullPath, replace: true, query: to.query })
    } else {
      const redirectPath = (from.query.redirect || to.path) as string
      const redirect = decodeURIComponent(redirectPath)
      const nextData = to.path === redirect ? { ...to, replace: true } : { path: redirect }
      next(nextData)
    }
  })
}
